
/*
From:
file:///D:/DDI/MovingForward/XMI/SDMetrics/SDMetricsOpenCore/src/com/sdmetrics/model/package.html
https://www.programcreek.com/java-api-examples/index.php?source_dir=RefDetector-master/src/gr/uom/java/xmi/XMIModelExtractor.java#

Required imports:
*/
import java.util.Collection;
import java.util.List;

import com.sdmetrics.model.MetaModel;
import com.sdmetrics.model.MetaModelElement;
import com.sdmetrics.model.Model;
import com.sdmetrics.model.ModelElement;
import com.sdmetrics.model.XMIReader;
import com.sdmetrics.model.XMITransformations;
import com.sdmetrics.util.XMLParser;

public class XMITest
{

	// method main(): ALWAYS the APPLICATION entry point
	public static void main( String[] args )
	{
		System.out.println( "Hello World!" );
		try
		{
			/*
			 * Have your metamodel, XMI transformation, and XMI input files ready: String
			 * metaModelURL = ...; // metamodel definition to use String xmiTransURL = ...; // XMI
			 * tranformations to use String xmiFile = ...; // XMI file with the UML model
			 */
			String metaModelURL = "src/com/sdmetrics/resources/metamodel2.xml"; // metamodel
																				// definition to use
			String xmiTransURL = "src/com/sdmetrics/resources/xmiTrans2_0.xml"; // XMI
																				// tranformations to
																				// use
			// https://bitbucket.org/wackerow/ddi4_xmi/raw/master/DDI4_PIM_canonical.xmi
			String xmiFile = "DDI4_PIM_canonical.xmi"; // XMI file with the UML model

			/*
			 * Read the metamodel {@link com.sdmetrics.util.XMLParser} {@link
			 * com.sdmetrics.model.MetaModel}
			 */
			XMLParser parser = new XMLParser();
			MetaModel metaModel = new MetaModel();
			parser.parse( metaModelURL, metaModel.getSAXParserHandler() );

			/*
			 * You do not have to use the SAX parser provided by class XMLParser, you may just as
			 * well use a org.xml.sax.XMLReader that you created yourself. Read the XMI
			 * transformation file {@link com.sdmetrics.model.XMITransformations}
			 */
			XMITransformations trans = new XMITransformations( metaModel );
			parser.parse( xmiTransURL, trans.getSAXParserHandler() );

			/*
			 * Read the XMI file with the UML model {@link com.sdmetrics.model.Model} {@link
			 * com.sdmetrics.model.XMIReader}
			 */
			Model model = new Model( metaModel );
			XMIReader xmiReader = new XMIReader( trans, model );
			parser.parse( xmiFile, xmiReader );

			/*
			 * Optionally, specify element filters to get rid of standard libraries or 3rd party
			 * APIs {@link com.sdmetrics.model.Model#setFilter}
			 */
			String[] filters = { "#.java", "#.javax", "#.org.xml" };
			model.setFilter( filters, false, true );

			/*
			 * At this point, you can already start calculating metrics for the elements in the
			 * model. The tutorial for package {@link com.sdmetrics.metrics} describes how. The
			 * remainder of this tutorial shows how to access the elements in the model. Access the
			 * UML model The following example writes all model elements accepted by the element
			 * filter to the console, along with the values of their attributes.
			 */
			// iterate over all model element types in the metamodel
			// {@link com.sdmetrics.model.MetaModelElement}
			for ( MetaModelElement type : metaModel )
			{
				System.out.println( "Elements of type: " + type.getName() );

				// iterate over all model elements of the current type
				List<ModelElement> elements = model.getAcceptedElements( type );
				// {@link com.sdmetrics.model.ModelElement}
				for ( ModelElement me : elements )
				{
					System.out.println( "  Element: " + me.getFullName() + " " );

					// write out the value of each attribute of the element
					Collection<String> attributeNames = type.getAttributeNames();
					for ( String attr : attributeNames )
					{
						System.out.print( "     Attribute '" + attr );
						if ( type.isSetAttribute( attr ) )
							System.out.println( "' has set value "
									+ me.getSetAttribute( attr ) );
						else if ( type.isRefAttribute( attr ) )
						{
							System.out.print( "' references " );
							ModelElement referenced = me.getRefAttribute( attr );
							System.out.println( (referenced == null) ? "nothing"
									: referenced.getFullName() );
						}
						else
							System.out.println( "' has value: "
									+ me.getPlainAttribute( attr ) );
					}
				}
			}
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}
}
